# ExportFieldMappingTestCaseExportField


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_field** | [**TestCaseExportField**](TestCaseExportField.md) |  | [optional] 
**name** | **str** |  | [optional] 

## Example

```python
from src.client.generated.models.export_field_mapping_test_case_export_field import ExportFieldMappingTestCaseExportField

# TODO update the JSON string below
json = "{}"
# create an instance of ExportFieldMappingTestCaseExportField from a JSON string
export_field_mapping_test_case_export_field_instance = ExportFieldMappingTestCaseExportField.from_json(json)
# print the JSON string representation of the object
print(ExportFieldMappingTestCaseExportField.to_json())

# convert the object into a dict
export_field_mapping_test_case_export_field_dict = export_field_mapping_test_case_export_field_instance.to_dict()
# create an instance of ExportFieldMappingTestCaseExportField from a dict
export_field_mapping_test_case_export_field_from_dict = ExportFieldMappingTestCaseExportField.from_dict(export_field_mapping_test_case_export_field_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


